@@ -1,7 +1,3 @@
-setClass("PcaCov", representation(delta = "numeric",
-                                    quan = "numeric"),
-                                contains="PcaRobust") 
-
 setMethod("getQuan", "PcaCov", function(obj) obj@n.obs)
 
 ##  The S3 version
@@ -19,7 +15,7 @@ PcaCov.formula <- function (formula, data = NULL, subset, na.action, ...)
     mf$... <- NULL
     mf[[1]] <- as.name("model.frame")
     mf <- eval.parent(mf)
-    ## this is not a `standard' model-fitting function,
+    ## this is not a 'standard' model-fitting function,
     ## so no need to consider contrasts or levels
     if (.check_vars_numeric(mf))
         stop("PCA applies only to numerical variables")
@@ -109,7 +105,7 @@ PcaCov.default <- function(x, k=0, kmax=ncol(x), corr=FALSE, cov.control = CovCo
                             eigenvalues=eigenvalues, 
                             center=center, 
                             scores=scores,
-                            k=p,
+                            k=k,
                             n.obs=n)
                
     ## Compute distances and flags
